@@ -1,5 +1,5 @@
 package Test::Count;
-
+$Test::Count::VERSION = '0.0902';
 use warnings;
 use strict;
 
@@ -44,12 +44,11 @@ sub _init
 
     my $in;
 
-    if (exists($args->{'filename'}))
+    if ( exists( $args->{'filename'} ) )
     {
-        $self->_filename($args->{'filename'});
+        $self->_filename( $args->{'filename'} );
         open $in, "<", $self->_filename()
-            or die "Could not open '" . $self->_filename() . "' - $!."
-        ;
+            or die "Could not open '" . $self->_filename() . "' - $!.";
     }
     else
     {
@@ -57,10 +56,10 @@ sub _init
     }
 
     $self->_in_fh($in);
-    if (exists($args->{'assert_prefix_regex'}))
+    if ( exists( $args->{'assert_prefix_regex'} ) )
     {
         my $re = $args->{'assert_prefix_regex'};
-        $self->_assert_prefix_regex((ref($re) eq "") ? qr{$re} : $re);
+        $self->_assert_prefix_regex( ( ref($re) eq "" ) ? qr{$re} : $re );
     }
     else
     {
@@ -70,15 +69,67 @@ sub _init
     return 0;
 }
 
-=encoding utf8
+
+sub process
+{
+    my $self = shift;
+    my $args = shift;
+
+    my $parser = $args->{parser} || Test::Count::Parser->new();
+
+    $parser->_push_current_filename( $self->_filename );
+
+    my $assert_re = $self->_assert_prefix_regex();
+
+    my @file_lines = readline( $self->_in_fh() );
+    close( $self->_in_fh() );
+
+    foreach my $idx ( 0 .. $#file_lines )
+    {
+        my $line = $file_lines[$idx];
+
+        chomp($line);
+        if ( $line =~ /${assert_re}:(.*)$/ )
+        {
+            $parser->update_assignments(
+                {
+                    'text' => $1,
+                }
+            );
+        }
+
+        # The \s* is to handle trailing whitespace properly.
+        elsif ( $line =~ /${assert_re}((?:[+*].*)?)\s*$/ )
+        {
+            my $s = $1;
+            $parser->update_count(
+                {
+                    'text' => ( ( $s eq "" ) ? 1 : substr( $s, 1 ) ),
+                }
+            );
+        }
+    }
+    $parser->_pop_current_filenames();
+
+    return { 'tests_count' => $parser->get_count(), 'lines' => \@file_lines, };
+}
+
+
+1;    # End of Test::Count
+
+__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Test::Count - Module for keeping track of the number of tests in a test script.
 
-=cut
+=head1 VERSION
 
-our $VERSION = '0.0901';
+version 0.0902
 
 =head1 SYNOPSIS
 
@@ -107,6 +158,10 @@ tests in the file is:
         %!perl -MTest::Count::Filter -e 'Test::Count::Filter->new({})->process()'
     endfunction
 
+=head1 VERSION
+
+version 0.0902
+
 =head1 FUNCTIONS
 
 =head2 my $counter = Test::Count->new({'input_fh' => \*MYFILEHANDLE});
@@ -140,51 +195,6 @@ The lines of the stream as is.
 
 =back
 
-=cut
-
-sub process
-{
-    my $self = shift;
-    my $args = shift;
-
-    my $parser = $args->{parser} || Test::Count::Parser->new();
-
-    $parser->_push_current_filename($self->_filename);
-
-    my $assert_re = $self->_assert_prefix_regex();
-
-    my @file_lines = readline($self->_in_fh());
-    close($self->_in_fh());
-
-    foreach my $idx (0 .. $#file_lines)
-    {
-        my $line = $file_lines[$idx];
-
-        chomp($line);
-        if ($line =~ /${assert_re}:(.*)$/)
-        {
-            $parser->update_assignments(
-                {
-                    'text' => $1,
-                }
-            );
-        }
-        # The \s* is to handle trailing whitespace properly.
-        elsif ($line =~ /${assert_re}((?:[+*].*)?)\s*$/)
-        {
-            my $s = $1;
-            $parser->update_count(
-                {
-                    'text' => (($s eq "") ? 1 : substr($s,1)),
-                }
-            );
-        }
-    }
-    $parser->_pop_current_filenames();
-
-    return { 'tests_count' => $parser->get_count(), 'lines' => \@file_lines,};
-}
-
 =head1 GRAMMAR DESCRIPTION
 
 You can put any mathematical expressions (using parentheses, C<+>, C<->,
@@ -330,6 +340,132 @@ Copyright 2006 Shlomi Fish.
 
 This program is released under the following license: MIT X11.
 
-=cut
+=head1 AUTHOR
 
-1; # End of Test::Count
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/test-count/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc Test::Count
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/Test-Count>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/Test-Count>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Count>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/Test-Count>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/Test-Count>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/Test-Count>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/T/Test-Count>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=Test-Count>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Test::Count>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-test-count at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Test-Count>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/test-count>
+
+  git clone git://github.com/shlomif/test-count.git
+
+=cut
